@@ -14,10 +14,6 @@ class S3HandlerTest(unittest.TestCase):
     def tearDown(self):
         pass
 
-    def test_runs(self):
-        """Basic smoke test"""
-        pass
-
     def test_aws_connector_init(self):
         handler = AwsS3SourceHandler(connector_contract=ConnectorContract(uri='s3://aistac-discovery-persist/persist/synthetic_member_claims.csv', module_name='', handler=''))
         result = handler.exists()
